@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
  * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org>
+ * * Copyright (C) 2012-2020 Sean Davis <bluesabre@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -458,15 +458,13 @@ parole_file_new_cdda_track(const gint track_num, const gchar *display_name) {
 ParoleFile *
 parole_file_new_dvd_chapter(gint chapter_num, const gchar *display_name) {
     ParoleFile *file = NULL;
-    gchar *uri = "dvd:/";
+    const gchar uri[] = "dvd:/";
 
     file = g_object_new(PAROLE_TYPE_FILE,
                         "filename", uri,
                         "display-name", display_name,
                         "dvd-chapter", chapter_num,
                         NULL);
-
-    // g_free(uri); FIXME This should probably be freed.
     return file;
 }
 
