@@ -1,7 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
- * * Copyright (C) 2012-2017 Sean Davis <smd.seandavis@gmail.com>
  * * Copyright (C) 2012-2017 Simon Steinbeiß <ochosi@xfce.org>
+ * * Copyright (C) 2012-2020 Sean Davis <bluesabre@xfce.org>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -200,6 +200,7 @@ parole_media_chooser_open_internal(ParoleMediaChooser *media_chooser) {
     GtkWidget      *file_chooser;
     GtkBuilder     *builder;
     GtkWidget      *recursive;
+    GtkWidget      *box;
     GtkFileFilter  *filter, *audio_filter, *video_filter, *playlist_filter, *all_files;
     gboolean        scan_recursive;
     gboolean        replace_playlist;
@@ -258,6 +259,9 @@ parole_media_chooser_open_internal(ParoleMediaChooser *media_chooser) {
 
     gtk_builder_connect_signals(builder, media_chooser);
 
+    box = GTK_WIDGET(gtk_builder_get_object(builder, "dialog-action_area1"));
+    gtk_widget_hide(box);
+
     g_object_unref(builder);
 }
 
